Sébastien Labbé Research Code
=============================

This is a `Sage <http://www.sagemath.org/>`_ optional package containing a part
of my own research code.  It contains modules on digital geometry,
combinatorics, combinatorics on words multidimensional continued fraction
algorithms, matrix cocycles, languages, substitutions, bispecial factors,
tikzpictures.

Links:

 - http://www.slabbe.org/Sage/
 - http://github.com/seblabbe/slabbe
 - http://pypi.python.org/pypi/slabbe

Usage::

    sage: from slabbe import *

Version 0.3b1 (June 12, 2016)
-------------------------------

Version ``0.3b1`` is a Python package now available on the Python Package index
(PyPI). It was migrated from the sage optional spkg format. It also adds code
to deal with bispecial factors.

Installation::

    sage -pip slabbe

Version 0.2 (November 25, 2015)
-------------------------------

Version ``0.2`` provides modules on multidimensional continued
fraction algorithms, matrix cocycles, languages and tikzpictures.  

    http://www.slabbe.org/Sage/slabbe-0.2.spkg

Documentation:

    http://www.slabbe.org/Sage/slabbe-0.2.pdf

Installation::

    sage -p http://www.slabbe.org/Sage/slabbe-0.2.spkg  # sage-6.9 or newer
    sage -i http://www.slabbe.org/Sage/slabbe-0.2.spkg  # sage-6.8 or earlier

Version 0.1.1 (June 3, 2015)
-----------------------------

This version fixes a bug with ``gcd`` import error.

    http://www.slabbe.org/Sage/slabbe-0.1.1.spkg

Installation::

    sage -i http://www.slabbe.org/Sage/slabbe-0.1.1.spkg

Version 0.1 (August 27, 2014)
-----------------------------

Version ``0.1`` contains modules on digital geometry, combinatorics on words
and more. 

    http://www.slabbe.org/Sage/slabbe-0.1.spkg

Documentation:

    http://www.slabbe.org/Sage/slabbe-0.1.pdf

Installation::

    sage -i http://www.slabbe.org/Sage/slabbe-0.1.spkg
